@@ -1,13 +1,14 @@
+#!/usr/bin/env python
 # Copyright FuseSoC contributors
 # Licensed under the 2-Clause BSD License, see LICENSE for details.
 # SPDX-License-Identifier: BSD-2-Clause
 
-#!/usr/bin/env python
 import argparse
 import os
+import signal
 import subprocess
 import sys
-import signal
+import warnings
 
 from fusesoc import __version__
 
@@ -18,16 +19,18 @@ fusesocdir = os.path.abspath(
 if os.path.exists(os.path.join(fusesocdir, "fusesoc")):
     sys.path[0:0] = [fusesocdir]
 
-from fusesoc.config import Config
-from fusesoc.coremanager import CoreManager, DependencyError
-from fusesoc.librarymanager import Library
-from fusesoc.edalizer import Edalizer
-from edalize import get_edatool
-from fusesoc.vlnv import Vlnv
-from fusesoc.utils import Launcher, setup_logging, yaml_fread
-
 import logging
 
+from edalize import get_edatool
+
+from fusesoc.config import Config
+from fusesoc.coreconverter import convert_core
+from fusesoc.coremanager import CoreManager, DependencyError
+from fusesoc.edalizer import Edalizer
+from fusesoc.librarymanager import Library
+from fusesoc.utils import Launcher, setup_logging, yaml_fread
+from fusesoc.vlnv import Vlnv
+
 logger = logging.getLogger(__name__)
 
 REPOS = [
@@ -67,35 +70,13 @@ def abort_handler(signal, frame):
 signal.signal(signal.SIGINT, abort_handler)
 
 
-def build(cm, args):
-    logger.warning(
-        "''build'' command is deprecated as it was intended to be used with CAPI1 format.\n"
-        "         It will be removed soon, so please use ''run'' command instead."
-    )
-
-    do_configure = True
-    do_build = not args.setup
-    do_run = False
-    if not args.target:
-        target = "synth"
-    else:
-        target = args.target
-    flags = {"target": target, "tool": args.tool}
-    run_backend(
-        cm,
-        not args.no_export,
-        do_configure,
-        do_build,
-        do_run,
-        flags,
-        None,
-        args.system,
-        args.backendargs,
-        None,
-    )
-
-
 def pgm(cm, args):
+    warnings.warn(
+        "The 'pgm' subcommand is deprecated and will be removed in the next "
+        "release. Use 'fusesoc run --target=synth --run' instead.",
+        FutureWarning,
+    )
+
     do_configure = False
     do_build = False
     do_run = True
@@ -125,6 +106,11 @@ def fetch(cm, args):
 
 
 def init(cm, args):
+    warnings.warn(
+        "The 'init' subcommand is deprecated and will be removed in the next "
+        "release. It was intended to fetch the FuseSoC standard library. This can be done with 'fusesoc library add fusesoc_cores https://github.com/fusesoc/fusesoc-cores' instead.",
+        FutureWarning,
+    )
     # Fix Python 2.x.
     global input
     try:
@@ -323,6 +309,25 @@ Usage       :
                 )
 
 
+def migrate_capi1_to_capi2(cm, args):
+    if not args.nowarn:
+        logger.warning(
+            "The CAPI1 -> CAPI2 core file conversion is best effort\n"
+            "and does not work in all situations. Carefully check the results\n"
+            "and manually fix problems. Refer to the CAPI2 reference manual at\n"
+            "https://fusesoc.readthedocs.io/en/master/ref/capi2.html for help."
+        )
+
+    if args.inplace:
+        output_file = args.input
+        if args.output:
+            logger.error(
+                "Argument error: --output and --inplace are mutually exclusive."
+            )
+            sys.exit(1)
+    convert_core(args.input, output_file)
+
+
 def core_info(cm, args):
     core = _get_core(cm, args.core)
     print(core.info())
@@ -412,7 +417,11 @@ def run_backend(
     if not os.path.exists(eda_api_file):
         do_configure = True
 
-    backend_class = get_edatool(tool)
+    try:
+        backend_class = get_edatool(tool)
+    except ImportError:
+        logger.error("Backend {!r} not found".format(tool))
+        exit(1)
 
     edalizer = Edalizer(
         toplevel=core.name,
@@ -445,11 +454,8 @@ def run_backend(
     # Frontend/backend separation
 
     try:
-        backend = get_edatool(tool)(edam=edam, work_root=work_root)
+        backend = backend_class(edam=edam, work_root=work_root)
 
-    except ImportError:
-        logger.error('Backend "{}" not found'.format(tool))
-        exit(1)
     except RuntimeError as e:
         logger.error(str(e))
         exit(1)
@@ -481,36 +487,6 @@ def run_backend(
             exit(1)
 
 
-def sim(cm, args):
-    logger.warning(
-        "''sim'' command is deprecated as it was intended to be used with CAPI1 format.\n"
-        "         It will be removed soon, so please use ''run'' command instead."
-    )
-
-    do_configure = not args.keep
-    do_build = not (args.setup or args.keep)
-    do_run = not (args.build_only or args.setup)
-
-    flags = {
-        "flow": "sim",
-        "tool": args.sim,
-        "target": "sim",
-        "testbench": args.testbench,
-    }
-    run_backend(
-        cm,
-        not args.no_export,
-        do_configure,
-        do_build,
-        do_run,
-        flags,
-        None,
-        args.system,
-        args.backendargs,
-        None,
-    )
-
-
 def update(cm, args):
     if "warn" in args:
         logger.warning(args.warn)
@@ -581,27 +557,9 @@ def parse_args():
     parser.add_argument("--verbose", help="More info messages", action="store_true")
     parser.add_argument("--log-file", help="Write log messages to file")
 
-    # build subparser
-    parser_build = subparsers.add_parser("build", help="Build an FPGA load module")
-    parser_build.add_argument(
-        "--no-export",
-        action="store_true",
-        help="Reference source files from their current location instead of exporting to a build tree",
-    )
-    parser_build.add_argument(
-        "--setup",
-        action="store_true",
-        help="Only create the project files without running the EDA tool",
-    )
-    parser_build.add_argument("--target", help="Override default target")
-    parser_build.add_argument("--tool", help="Override default tool for target")
-    parser_build.add_argument("system")
-    parser_build.add_argument("backendargs", nargs=argparse.REMAINDER)
-    parser_build.set_defaults(func=build)
-
     # init subparser
     parser_init = subparsers.add_parser(
-        "init", help="Initialize the FuseSoC core libraries"
+        "init", help="Initialize the FuseSoC core libraries. DEPRECATED"
     )
     parser_init.add_argument(
         "-y", action="store_true", help="Skip user input and use default settings"
@@ -610,7 +568,8 @@ def parse_args():
 
     # pgm subparser
     parser_pgm = subparsers.add_parser(
-        "pgm", help="Program an FPGA with a system configuration"
+        "pgm",
+        help="Program an FPGA with a system configuration. DEPRECATED, use 'run' instead.",
     )
     parser_pgm.add_argument("system")
     parser_pgm.add_argument("backendargs", nargs=argparse.REMAINDER)
@@ -645,6 +604,23 @@ def parse_args():
     parser_list_cores = subparsers.add_parser("list-cores", help="List available cores")
     parser_list_cores.set_defaults(func=list_cores)
 
+    # migrate-capi1-to-capi2 subparser
+    parser_conv = subparsers.add_parser(
+        "migrate-capi1-to-capi2",
+        help="Convert a CAPI1 core file into the CAPI2 file format",
+    )
+    parser_conv.add_argument(
+        "input", metavar="CAPI1_FILE", type=str, help="CAPI1 input file"
+    )
+    parser_conv.add_argument("--output", "-o", type=str, help="CAPI2 output file.")
+    parser_conv.add_argument(
+        "--inplace", "-i", action="store_true", help="Convert the input file in place."
+    )
+    parser_conv.add_argument(
+        "--nowarn", action="store_true", help="Do not display warning banner."
+    )
+    parser_conv.set_defaults(func=migrate_capi1_to_capi2)
+
     # core-info subparser
     parser_core_info = subparsers.add_parser(
         "core-info", help="Display details about a core"
@@ -759,42 +735,6 @@ def parse_args():
     )
     parser_run.set_defaults(func=run)
 
-    # sim subparser
-    parser_sim = subparsers.add_parser("sim", help="Setup and run a simulation")
-    parser_sim.add_argument(
-        "--no-export",
-        action="store_true",
-        help="Reference source files from their current location instead of exporting to a build tree",
-    )
-    parser_sim.add_argument(
-        "--sim", help="Override the simulator settings from the system file"
-    )
-    parser_sim.add_argument(
-        "--setup",
-        action="store_true",
-        help="Only create the project files without running the EDA tool",
-    )
-    parser_sim.add_argument(
-        "--build-only",
-        action="store_true",
-        help="Build the simulation binary without running the simulator",
-    )
-    parser_sim.add_argument(
-        "--force",
-        action="store_true",
-        help="Force rebuilding simulation model when directory exists",
-    )
-    parser_sim.add_argument(
-        "--keep",
-        action="store_true",
-        help="Prevent rebuilding simulation model if it exists",
-    )
-    parser_sim.add_argument("--target", help="Override default target")
-    parser_sim.add_argument("--testbench", help="Override default testbench")
-    parser_sim.add_argument("system", help="Select a system to simulate")
-    parser_sim.add_argument("backendargs", nargs=argparse.REMAINDER)
-    parser_sim.set_defaults(func=sim)
-
     # update subparser
     parser_update = subparsers.add_parser(
         "update", help="Update the FuseSoC core libraries"
