@@ -5,6 +5,7 @@
 import logging
 import os
 import shutil
+
 from fusesoc.provider.provider import Provider
 from fusesoc.utils import Launcher
 
@@ -13,6 +14,9 @@ logger = logging.getLogger(__name__)
 
 class Coregen(Provider):
     def _checkout(self, local_dir):
+        logger.warning(
+            "The coregen provider is deprecated and will be removed. Consider using a generator for this instead"
+        )
         script_file = self.config.get("script_file")
         project_file = self.config.get("project_file")
         extra_files = self.config.get("extra_files")
